aboutsummaryrefslogtreecommitdiffstats
path: root/etc/taskcluster/decision_task.py
diff options
context:
space:
mode:
authorbors-servo <lbergstrom+bors@mozilla.com>2020-01-03 19:08:08 -0500
committerGitHub <noreply@github.com>2020-01-03 19:08:08 -0500
commitde50b4142b364f76d50f2bc43d4db030450bfdce (patch)
tree3c5cac53e386c2749e5f24a4fd5150ef00ecd593 /etc/taskcluster/decision_task.py
parent2488213d18d5bc9806b41fb2756a2a82dbe933a4 (diff)
parent8fc072a375378dcc73d2e348d8e46a4d735e6210 (diff)
downloadservo-de50b4142b364f76d50f2bc43d4db030450bfdce.tar.gz
servo-de50b4142b364f76d50f2bc43d4db030450bfdce.zip
Auto merge of #25417 - servo:profile, r=jdm,Manishearth
mach: automatically use the 'minimal' rustup profile + rustc-dev component Fixes https://github.com/servo/servo/issues/25401 Fixes https://github.com/servo/servo/issues/25402
Diffstat (limited to 'etc/taskcluster/decision_task.py')
-rw-r--r--etc/taskcluster/decision_task.py31
1 files changed, 6 insertions, 25 deletions
diff --git a/etc/taskcluster/decision_task.py b/etc/taskcluster/decision_task.py
index a3d70653794..6f8d41e3cb8 100644
--- a/etc/taskcluster/decision_task.py
+++ b/etc/taskcluster/decision_task.py
@@ -181,9 +181,6 @@ def linux_tidy_unit_untrusted():
.with_dockerfile(dockerfile_path("build"))
.with_env(**build_env, **unix_build_env, **linux_build_env)
.with_repo_bundle()
- .with_script("rustup set profile minimal")
- # required by components/script_plugins:
- .with_script("rustup component add rustc-dev")
.with_script("""
./mach test-tidy --no-progress --all
./mach test-tidy --no-progress --self-test
@@ -229,7 +226,6 @@ def linux_docs_check():
linux_build_task("Docs + check")
.with_treeherder("Linux x64", "Doc+Check")
.with_script("""
- rustup component add rust-docs
RUSTDOCFLAGS="--disable-minification" ./mach doc
(
cd target/doc
@@ -304,11 +300,10 @@ def with_rust_nightly():
modified_build_env["RUSTFLAGS"] = " ".join(flags)
return (
- linux_build_task("with Rust Nightly", build_env=modified_build_env, install_rustc_dev=False)
+ linux_build_task("with Rust Nightly", build_env=modified_build_env)
.with_treeherder("Linux x64", "RustNightly")
.with_script("""
echo "nightly" > rust-toolchain
- rustup component add rustc-dev
./mach build --dev
./mach test-unit
""")
@@ -850,7 +845,7 @@ def macos_task(name):
)
-def linux_build_task(name, *, build_env=build_env, install_rustc_dev=True):
+def linux_build_task(name, *, build_env=build_env):
task = (
linux_task(name)
# https://docs.taskcluster.net/docs/reference/workers/docker-worker/docs/caches
@@ -867,14 +862,8 @@ def linux_build_task(name, *, build_env=build_env, install_rustc_dev=True):
.with_dockerfile(dockerfile_path("build"))
.with_env(**build_env, **unix_build_env, **linux_build_env)
.with_repo_bundle()
- .with_script("""
- rustup set profile minimal
- ./mach bootstrap-gstreamer
- """)
+ .with_script("./mach bootstrap-gstreamer")
)
- if install_rustc_dev:
- # required by components/script_plugins:
- task = task.with_script("rustup component add rustc-dev")
return task
@@ -884,9 +873,9 @@ def android_build_task(name):
# file: NDK parses $(file $SHELL) to tell x64 host from x86
# wget: servo-media-gstreamer’s build script
.with_script("""
- apt-get update -q
- apt-get install -y --no-install-recommends openjdk-8-jdk-headless file wget
- ./mach bootstrap-android --accept-all-licences --build
+ time apt-get update -q
+ time apt-get install -y --no-install-recommends openjdk-8-jdk-headless file wget
+ time ./mach bootstrap-android --accept-all-licences --build
""")
)
@@ -920,9 +909,6 @@ def windows_build_task(name, package=True, arch="x86_64"):
path="python3",
)
.with_rustup()
- .with_script("rustup set profile minimal")
- # required by components/script_plugins:
- .with_script("rustup component add rustc-dev")
)
if arch in hashes["non-devel"] and arch in hashes["devel"]:
task = (
@@ -968,11 +954,6 @@ def macos_build_task(name):
.with_repo_bundle(alternate_object_dir="/var/cache/servo.git/objects")
.with_python2()
.with_rustup()
- # Since macOS workers are long-lived and ~/.rustup kept across tasks:
- .with_script("rustup self update")
- .with_script("rustup set profile minimal")
- # required by components/script_plugins:
- .with_script("rustup component add rustc-dev")
.with_index_and_artifacts_expire_in(build_artifacts_expire_in)
# Debugging for surprising generic-worker behaviour
.with_early_script("ls")